@@ -47,6 +47,8 @@ import warnings
 from pyfakefs.deprecator import Deprecator
 from pyfakefs.fake_filesystem import set_uid, set_gid, reset_ids
 from pyfakefs.helpers import IS_PYPY
+from pyfakefs.patched_packages import get_modules_to_patch, \
+    get_classes_to_patch, get_fake_module_classes
 
 try:
     from importlib.machinery import ModuleSpec
@@ -57,11 +59,10 @@ from importlib import reload
 
 from pyfakefs import fake_filesystem
 from pyfakefs import fake_filesystem_shutil
+from pyfakefs import fake_pathlib
 from pyfakefs import mox3_stubout
 from pyfakefs.extra_packages import pathlib, pathlib2, use_scandir
 
-if pathlib:
-    from pyfakefs import fake_pathlib
 
 if use_scandir:
     from pyfakefs import fake_scandir
@@ -71,33 +72,23 @@ PATH_MODULE = 'ntpath' if sys.platform == 'win32' else 'posixpath'
 BUILTIN_MODULE = '__builtin__'
 
 
-def _patchfs(f):
-    """Internally used to be able to use patchfs without parentheses."""
-
-    @functools.wraps(f)
-    def decorated(*args, **kwargs):
-        with Patcher() as p:
-            kwargs['fs'] = p.fs
-            return f(*args, **kwargs)
-
-    return decorated
-
-
-def patchfs(additional_skip_names=None,
+def patchfs(_func=None, *,
+            additional_skip_names=None,
             modules_to_reload=None,
             modules_to_patch=None,
-            allow_root_user=True):
+            allow_root_user=True,
+            use_known_patches=True):
     """Convenience decorator to use patcher with additional parameters in a
     test function.
 
     Usage::
 
         @patchfs
-        test_my_function(fs):
+        def test_my_function(fs):
             fs.create_file('foo')
 
         @patchfs(allow_root_user=False)
-        test_with_patcher_args(fs):
+        def test_with_patcher_args(fs):
             os.makedirs('foo/bar')
     """
 
@@ -108,19 +99,20 @@ def patchfs(additional_skip_names=None,
                     additional_skip_names=additional_skip_names,
                     modules_to_reload=modules_to_reload,
                     modules_to_patch=modules_to_patch,
-                    allow_root_user=allow_root_user) as p:
+                    allow_root_user=allow_root_user,
+                    use_known_patches=use_known_patches) as p:
                 kwargs['fs'] = p.fs
                 return f(*args, **kwargs)
 
         return wrapped
 
-    # workaround to be able to use the decorator without using calling syntax
-    # (the default usage without parameters)
-    # if using the decorator without parentheses, the first argument here
-    # will be the wrapped function, so we pass it to the decorator function
-    # that doesn't use arguments
-    if inspect.isfunction(additional_skip_names):
-        return _patchfs(additional_skip_names)
+    if _func:
+        if not callable(_func):
+            raise TypeError(
+                "Decorator argument not a function.\n"
+                "Did you mean `@patchfs(additional_skip_names=...)`?"
+            )
+        return wrap_patchfs(_func)
 
     return wrap_patchfs
 
@@ -129,7 +121,8 @@ def load_doctests(loader, tests, ignore, module,
                   additional_skip_names=None,
                   modules_to_reload=None,
                   modules_to_patch=None,
-                  allow_root_user=True):  # pylint: disable=unused-argument
+                  allow_root_user=True,
+                  use_known_patches=True):  # pylint: disable=unused-argument
     """Load the doctest tests for the specified module into unittest.
         Args:
             loader, tests, ignore : arguments passed in from `load_tests()`
@@ -141,7 +134,8 @@ def load_doctests(loader, tests, ignore, module,
     _patcher = Patcher(additional_skip_names=additional_skip_names,
                        modules_to_reload=modules_to_reload,
                        modules_to_patch=modules_to_patch,
-                       allow_root_user=allow_root_user)
+                       allow_root_user=allow_root_user,
+                       use_known_patches=use_known_patches)
     globs = _patcher.replace_globs(vars(module))
     tests.addTests(doctest.DocTestSuite(module,
                                         globs=globs,
@@ -167,6 +161,8 @@ class TestCaseMixin:
         modules_to_patch: A dictionary of fake modules mapped to the
             fully qualified patched module names. Can be used to add patching
             of modules not provided by `pyfakefs`.
+        use_known_patches: If True (the default), some patches for commonly
+            used packges are applied which make them usable with pyfakes.
 
     If you specify some of these attributes here and you have DocTests,
     consider also specifying the same arguments to :py:func:`load_doctests`.
@@ -202,7 +198,8 @@ class TestCaseMixin:
                       additional_skip_names=None,
                       modules_to_reload=None,
                       modules_to_patch=None,
-                      allow_root_user=True):
+                      allow_root_user=True,
+                      use_known_patches=True):
         """Bind the file-related modules to the :py:class:`pyfakefs` fake file
         system instead of the real file system.  Also bind the fake `open()`
         function.
@@ -224,7 +221,8 @@ class TestCaseMixin:
             additional_skip_names=additional_skip_names,
             modules_to_reload=modules_to_reload,
             modules_to_patch=modules_to_patch,
-            allow_root_user=allow_root_user
+            allow_root_user=allow_root_user,
+            use_known_patches=use_known_patches
         )
 
         self._stubber.setUp()
@@ -259,7 +257,8 @@ class TestCase(unittest.TestCase, TestCaseMixin):
                  additional_skip_names=None,
                  modules_to_reload=None,
                  modules_to_patch=None,
-                 allow_root_user=True):
+                 allow_root_user=True,
+                 use_known_patches=True):
         """Creates the test class instance and the patcher used to stub out
         file system related modules.
 
@@ -273,6 +272,7 @@ class TestCase(unittest.TestCase, TestCaseMixin):
         self.modules_to_reload = modules_to_reload
         self.modules_to_patch = modules_to_patch
         self.allow_root_user = allow_root_user
+        self.use_known_patches = use_known_patches
 
     @Deprecator('add_real_file')
     def copyRealFile(self, real_file_path, fake_file_path=None,
@@ -346,14 +346,10 @@ class Patcher:
     IS_WINDOWS = sys.platform in ('win32', 'cygwin')
 
     SKIPNAMES = {'os', 'path', 'io', 'genericpath', OS_MODULE, PATH_MODULE}
-    if pathlib:
-        SKIPNAMES.add('pathlib')
-    if pathlib2:
-        SKIPNAMES.add('pathlib2')
 
     def __init__(self, additional_skip_names=None,
                  modules_to_reload=None, modules_to_patch=None,
-                 allow_root_user=True):
+                 allow_root_user=True, use_known_patches=True):
         """For a description of the arguments, see TestCase.__init__"""
 
         if not allow_root_user:
@@ -377,6 +373,12 @@ class Patcher:
 
         self.modules_to_reload = modules_to_reload or []
 
+        if use_known_patches:
+            modules_to_patch = modules_to_patch or {}
+            modules_to_patch.update(get_modules_to_patch())
+            self._class_modules.update(get_classes_to_patch())
+            self._fake_module_classes.update(get_fake_module_classes())
+
         if modules_to_patch is not None:
             for name, fake_module in modules_to_patch.items():
                 self._fake_module_classes[name] = fake_module
@@ -415,18 +417,17 @@ class Patcher:
         # class modules maps class names against a list of modules they can
         # be contained in - this allows for alternative modules like
         # `pathlib` and `pathlib2`
+        self._class_modules['Path'] = []
         if pathlib:
-            self._class_modules['Path'] = []
-            if pathlib:
-                self._fake_module_classes[
-                    'pathlib'] = fake_pathlib.FakePathlibModule
-                self._class_modules['Path'].append('pathlib')
-            if pathlib2:
-                self._fake_module_classes[
-                    'pathlib2'] = fake_pathlib.FakePathlibModule
-                self._class_modules['Path'].append('pathlib2')
             self._fake_module_classes[
-                'Path'] = fake_pathlib.FakePathlibPathModule
+                'pathlib'] = fake_pathlib.FakePathlibModule
+            self._class_modules['Path'].append('pathlib')
+        if pathlib2:
+            self._fake_module_classes[
+                'pathlib2'] = fake_pathlib.FakePathlibModule
+            self._class_modules['Path'].append('pathlib2')
+        self._fake_module_classes[
+            'Path'] = fake_pathlib.FakePathlibPathModule
         if use_scandir:
             self._fake_module_classes[
                 'scandir'] = fake_scandir.FakeScanDirModule
@@ -533,7 +534,6 @@ class Patcher:
                 # where py.error has no __name__ attribute
                 # see https://github.com/pytest-dev/py/issues/73
                 continue
-
             module_items = module.__dict__.copy().items()
 
             # suppress specific pytest warning - see #466
