@@ -21,40 +21,26 @@ from stat import S_IFLNK
 
 import os
 
-IS_PY2 = sys.version_info[0] < 3
 IS_PYPY = platform.python_implementation() == 'PyPy'
 IS_WIN = sys.platform == 'win32'
 IN_DOCKER = os.path.exists('/.dockerenv')
 
-try:
-    text_type = unicode  # Python 2
-except NameError:
-    text_type = str      # Python 3
-
 
 def is_int_type(val):
     """Return True if `val` is of integer type."""
-    try:               # Python 2
-        return isinstance(val, (int, long))
-    except NameError:  # Python 3
-        return isinstance(val, int)
+    return isinstance(val, int)
 
 
 def is_byte_string(val):
     """Return True if `val` is a bytes-like object, False for a unicode
     string."""
-    if not IS_PY2:
-        return not hasattr(val, 'encode')
-    return isinstance(val, (memoryview, str))
+    return not hasattr(val, 'encode')
 
 
 def is_unicode_string(val):
     """Return True if `val` is a unicode string, False for a bytes-like
     object."""
-    try:               # Python 2
-        return isinstance(val, unicode)
-    except NameError:  # Python 3
-        return hasattr(val, 'encode')
+    return hasattr(val, 'encode')
 
 
 def make_string_path(dir_name):
@@ -63,16 +49,31 @@ def make_string_path(dir_name):
     return dir_name
 
 
-class FakeStatResult(object):
+def to_string(path):
+    """Return the string representation of a byte string using the preferred
+     encoding, or the string itself if path is a str."""
+    if isinstance(path, bytes):
+        return path.decode(locale.getpreferredencoding(False))
+    return path
+
+
+def matching_string(matched, string):
+    """Return the string as byte or unicode depending
+    on the type of matched, assuming string is an ASCII string.
+    """
+    if string is None:
+        return string
+    if isinstance(matched, bytes) and isinstance(string, str):
+        return string.encode(locale.getpreferredencoding(False))
+    return string
+
+
+class FakeStatResult:
     """Mimics os.stat_result for use as return type of `stat()` and similar.
     This is needed as `os.stat_result` has no possibility to set
     nanosecond times directly.
     """
-    try:
-        long_type = long  # Python 2
-    except NameError:
-        long_type = int   # Python 3
-    _stat_float_times = sys.version_info >= (2, 5)
+    _stat_float_times = True
 
     def __init__(self, is_windows, user_id, group_id, initial_time=None):
         self._use_float = None
@@ -85,7 +86,7 @@ class FakeStatResult(object):
         self._st_size = None
         self.is_windows = is_windows
         if initial_time is not None:
-            self._st_atime_ns = self.long_type(initial_time * 1e9)
+            self._st_atime_ns = int(initial_time * 1e9)
         else:
             self._st_atime_ns = None
         self._st_mtime_ns = self._st_atime_ns
@@ -103,17 +104,17 @@ class FakeStatResult(object):
 
     def __eq__(self, other):
         return (
-            isinstance(other, FakeStatResult) and
-            self._st_atime_ns == other._st_atime_ns and
-            self._st_ctime_ns == other._st_ctime_ns and
-            self._st_mtime_ns == other._st_mtime_ns and
-            self.st_size == other.st_size and
-            self.st_gid == other.st_gid and
-            self.st_uid == other.st_uid and
-            self.st_nlink == other.st_nlink and
-            self.st_dev == other.st_dev and
-            self.st_ino == other.st_ino and
-            self.st_mode == other.st_mode
+                isinstance(other, FakeStatResult) and
+                self._st_atime_ns == other._st_atime_ns and
+                self._st_ctime_ns == other._st_ctime_ns and
+                self._st_mtime_ns == other._st_mtime_ns and
+                self.st_size == other.st_size and
+                self.st_gid == other.st_gid and
+                self.st_uid == other.st_uid and
+                self.st_nlink == other.st_nlink and
+                self.st_dev == other.st_dev and
+                self.st_ino == other.st_ino and
+                self.st_mode == other.st_mode
         )
 
     def __ne__(self, other):
@@ -136,14 +137,9 @@ class FakeStatResult(object):
         self.st_uid = stat_result.st_uid
         self.st_gid = stat_result.st_gid
         self._st_size = stat_result.st_size
-        if sys.version_info < (3, 3):
-            self._st_atime_ns = self.long_type(stat_result.st_atime * 1e9)
-            self._st_mtime_ns = self.long_type(stat_result.st_mtime * 1e9)
-            self._st_ctime_ns = self.long_type(stat_result.st_ctime * 1e9)
-        else:
-            self._st_atime_ns = stat_result.st_atime_ns
-            self._st_mtime_ns = stat_result.st_mtime_ns
-            self._st_ctime_ns = stat_result.st_ctime_ns
+        self._st_atime_ns = stat_result.st_atime_ns
+        self._st_mtime_ns = stat_result.st_mtime_ns
+        self._st_ctime_ns = stat_result.st_ctime_ns
 
     @classmethod
     def stat_float_times(cls, newvalue=None):
@@ -182,17 +178,17 @@ class FakeStatResult(object):
     @st_ctime.setter
     def st_ctime(self, val):
         """Set the creation time in seconds."""
-        self._st_ctime_ns = self.long_type(val * 1e9)
+        self._st_ctime_ns = int(val * 1e9)
 
     @st_atime.setter
     def st_atime(self, val):
         """Set the access time in seconds."""
-        self._st_atime_ns = self.long_type(val * 1e9)
+        self._st_atime_ns = int(val * 1e9)
 
     @st_mtime.setter
     def st_mtime(self, val):
         """Set the modification time in seconds."""
-        self._st_mtime_ns = self.long_type(val * 1e9)
+        self._st_mtime_ns = int(val * 1e9)
 
     @property
     def st_size(self):
@@ -206,7 +202,7 @@ class FakeStatResult(object):
 
     @property
     def st_file_attributes(self):
-        if not self.is_windows or sys.version_info < (3, 5):
+        if not self.is_windows:
             raise AttributeError("module 'os.stat_result' "
                                  "has no attribute 'st_file_attributes'")
         mode = 0
@@ -257,45 +253,45 @@ class FakeStatResult(object):
             return int(self.st_ctime)
         raise ValueError('Invalid item')
 
-    if sys.version_info >= (3, 3):
-        @property
-        def st_atime_ns(self):
-            """Return the access time in nanoseconds."""
-            return self._st_atime_ns
+    @property
+    def st_atime_ns(self):
+        """Return the access time in nanoseconds."""
+        return self._st_atime_ns
 
-        @property
-        def st_mtime_ns(self):
-            """Return the modification time in nanoseconds."""
-            return self._st_mtime_ns
+    @property
+    def st_mtime_ns(self):
+        """Return the modification time in nanoseconds."""
+        return self._st_mtime_ns
 
-        @property
-        def st_ctime_ns(self):
-            """Return the creation time in nanoseconds."""
-            return self._st_ctime_ns
+    @property
+    def st_ctime_ns(self):
+        """Return the creation time in nanoseconds."""
+        return self._st_ctime_ns
 
-        @st_atime_ns.setter
-        def st_atime_ns(self, val):
-            """Set the access time in nanoseconds."""
-            self._st_atime_ns = val
+    @st_atime_ns.setter
+    def st_atime_ns(self, val):
+        """Set the access time in nanoseconds."""
+        self._st_atime_ns = val
 
-        @st_mtime_ns.setter
-        def st_mtime_ns(self, val):
-            """Set the modification time of the fake file in nanoseconds."""
-            self._st_mtime_ns = val
+    @st_mtime_ns.setter
+    def st_mtime_ns(self, val):
+        """Set the modification time of the fake file in nanoseconds."""
+        self._st_mtime_ns = val
 
-        @st_ctime_ns.setter
-        def st_ctime_ns(self, val):
-            """Set the creation time of the fake file in nanoseconds."""
-            self._st_ctime_ns = val
+    @st_ctime_ns.setter
+    def st_ctime_ns(self, val):
+        """Set the creation time of the fake file in nanoseconds."""
+        self._st_ctime_ns = val
 
 
-class FileBufferIO(object):
-    """Stream class that handles both Python2 and Python3 string and
-    byte contents for files. The standard io.StringIO cannot be used
-    for strings due to the slightly different handling of newline mode.
+class FileBufferIO:
+    """Stream class that handles Python string and byte contents for files.
+    The standard io.StringIO cannot be used for strings due to the slightly
+    different handling of newline mode.
     Uses an io.BytesIO stream for the raw data and adds handling of encoding
     and newlines.
     """
+
     def __init__(self, contents=None, linesep='\n', binary=False,
                  newline=None, encoding=None, errors='strict'):
         self._newline = newline
@@ -317,8 +313,6 @@ class FileBufferIO(object):
         return contents.encode(self.encoding(), self.errors)
 
     def decoded_string(self, contents):
-        if IS_PY2 and not self._encoding:
-            return contents
         return contents.decode(self.encoding(), self.errors)
 
     def convert_newlines_for_writing(self, s):
@@ -418,7 +412,7 @@ class FileBufferIO(object):
         self._bytestream.write(self.encoded_string(s))
 
     def write(self, s):
-        if not IS_PY2 and self.binary != is_byte_string(s):
+        if self.binary != is_byte_string(s):
             raise TypeError('Incorrect type for writing')
         contents = self.convert_newlines_for_writing(s)
         length = len(contents)
@@ -438,15 +432,12 @@ class FileBufferIO(object):
             raise StopIteration
         return line
 
-    # Python 2 version
-    def next(self):
-        return self.__next__()
-
     def __getattr__(self, name):
         return getattr(self._bytestream, name)
 
 
 class NullFileBufferIO(FileBufferIO):
     """Special stream for null device. Does nothing on writing."""
+
     def putvalue(self, s):
         pass
