@@ -119,7 +119,6 @@ class TestPyfakefsUnittest(TestPyfakefsUnittestBase):  # pylint: disable=R0904
         shutil.rmtree('/test/dir1')
         self.assertFalse(self.fs.exists('/test/dir1'))
 
-    @unittest.skipIf(not pathlib, "only run if pathlib is available")
     def test_fakepathlib(self):
         with pathlib.Path('/fake_file.txt') as p:
             with p.open('w') as f:
@@ -147,12 +146,11 @@ class TestPatchingImports(TestPyfakefsUnittestBase):
         self.assertTrue(
             pyfakefs.tests.import_as_example.check_if_exists2(file_path))
 
-    if pathlib:
-        def test_import_path_from_pathlib(self):
-            file_path = '/foo/bar'
-            self.fs.create_dir(file_path)
-            self.assertTrue(
-                pyfakefs.tests.import_as_example.check_if_exists3(file_path))
+    def test_import_path_from_pathlib(self):
+        file_path = '/foo/bar'
+        self.fs.create_dir(file_path)
+        self.assertTrue(
+            pyfakefs.tests.import_as_example.check_if_exists3(file_path))
 
     def test_import_function_from_os_path(self):
         file_path = '/foo/bar'
@@ -363,12 +361,14 @@ class NoRootUserTest(fake_filesystem_unittest.TestCase):
         dir_path = '/foo/bar'
         self.fs.create_dir(dir_path, perm_bits=0o555)
         file_path = dir_path + 'baz'
-        self.assertRaises(OSError, self.fs.create_file, file_path)
+        with self.assertRaises(OSError):
+            self.fs.create_file(file_path)
 
         file_path = '/baz'
         self.fs.create_file(file_path)
         os.chmod(file_path, 0o400)
-        self.assertRaises(OSError, open, file_path, 'w')
+        with self.assertRaises(OSError):
+            open(file_path, 'w')
 
 
 class PauseResumeTest(TestPyfakefsUnittestBase):
@@ -435,7 +435,8 @@ class PauseResumeTest(TestPyfakefsUnittestBase):
 
     def test_pause_resume_without_patcher(self):
         fs = fake_filesystem.FakeFilesystem()
-        self.assertRaises(RuntimeError, fs.resume)
+        with self.assertRaises(RuntimeError):
+            fs.resume()
 
 
 class PauseResumePatcherTest(fake_filesystem_unittest.TestCase):
@@ -646,5 +647,17 @@ class TestDistutilsCopyTree(fake_filesystem_unittest.TestCase):
         self.assertFalse(os.path.isdir('./test2/'))
 
 
+class PathlibTest(TestCase):
+    """Regression test for #527"""
+
+    @patchfs
+    def test_cwd(self, fs):
+        """Make sure fake file system is used for os in pathlib"""
+        self.assertEqual(os.path.sep, str(pathlib.Path.cwd()))
+        dot_abs = pathlib.Path(".").absolute()
+        self.assertEqual(os.path.sep, str(dot_abs))
+        self.assertTrue(dot_abs.exists())
+
+
 if __name__ == "__main__":
     unittest.main()
