@@ -23,7 +23,7 @@ FileTime = namedtuple('FileTime', 'st_ctime, st_atime, st_mtime')
 class FakeStatTestBase(RealFsTestCase):
 
     def setUp(self):
-        super(FakeStatTestBase, self).setUp()
+        super().setUp()
         # we disable the tests for MacOS to avoid very long builds due
         # to the 1s time resolution - we know that the functionality is
         # similar to Linux
@@ -174,7 +174,7 @@ class FakeStatTestBase(RealFsTestCase):
         self.assertLessExceptWindows(written.st_ctime, closed.st_ctime)
 
         self.assertEqual(created.st_atime, written.st_atime)
-        self.assertEqual(written.st_atime, closed.st_atime)
+        self.assertLessEqual(written.st_atime, closed.st_atime)
 
         self.assertEqual(created.st_mtime, written.st_mtime)
         self.assertLess(written.st_mtime, closed.st_mtime)
@@ -189,7 +189,7 @@ class FakeStatTestBase(RealFsTestCase):
         self.assertLessExceptWindows(before.st_ctime, opened.st_ctime)
         self.assertEqual(opened.st_ctime, closed.st_ctime)
 
-        self.assertEqual(before.st_atime, opened.st_atime)
+        self.assertLessEqual(before.st_atime, opened.st_atime)
         self.assertEqual(opened.st_atime, closed.st_atime)
 
         self.assertLess(before.st_mtime, opened.st_mtime)
@@ -223,9 +223,9 @@ class FakeStatTestBase(RealFsTestCase):
         self.assertEqual(opened.st_ctime, written.st_ctime)
         self.assertLessExceptWindows(written.st_ctime, closed.st_ctime)
 
-        self.assertEqual(before.st_atime, opened.st_atime)
+        self.assertLessEqual(before.st_atime, opened.st_atime)
         self.assertEqual(opened.st_atime, written.st_atime)
-        self.assertEqual(written.st_atime, closed.st_atime)
+        self.assertLessEqual(written.st_atime, closed.st_atime)
 
         self.assertLess(before.st_mtime, opened.st_mtime)
         self.assertEqual(opened.st_mtime, written.st_mtime)
@@ -243,7 +243,7 @@ class FakeStatTestBase(RealFsTestCase):
         self.assertEqual(opened.st_ctime, flushed.st_ctime)
         self.assertEqual(flushed.st_ctime, closed.st_ctime)
 
-        self.assertEqual(before.st_atime, opened.st_atime)
+        self.assertLessEqual(before.st_atime, opened.st_atime)
         self.assertEqual(opened.st_atime, flushed.st_atime)
         self.assertEqual(flushed.st_atime, closed.st_atime)
 
@@ -319,7 +319,7 @@ class FakeStatTestBase(RealFsTestCase):
 
         self.assertEqual(before.st_atime, opened.st_atime)
         self.assertEqual(opened.st_atime, written.st_atime)
-        self.assertEqual(written.st_atime, closed.st_atime)
+        self.assertLessEqual(written.st_atime, closed.st_atime)
 
         self.assertEqual(before.st_mtime, opened.st_mtime)
         self.assertEqual(opened.st_mtime, written.st_mtime)
@@ -339,15 +339,15 @@ class FakeStatTestBase(RealFsTestCase):
         self.assertEqual(opened.st_ctime, written.st_ctime)
         self.assertEqual(flushed.st_ctime, closed.st_ctime)
 
-        self.assertEqual(before.st_atime, opened.st_atime)
+        self.assertLessEqual(before.st_atime, opened.st_atime)
         self.assertEqual(opened.st_atime, written.st_atime)
-        self.assertEqual(written.st_atime, flushed.st_atime)
+        self.assertLessEqual(written.st_atime, flushed.st_atime)
         self.assertEqual(flushed.st_atime, closed.st_atime)
 
         self.assertLess(before.st_mtime, opened.st_mtime)
         self.assertEqual(opened.st_mtime, written.st_mtime)
         self.assertLessExceptWindows(written.st_mtime, flushed.st_mtime)
-        self.assertLessExceptPosix(flushed.st_mtime, closed.st_mtime)
+        self.assertLessEqual(flushed.st_mtime, closed.st_mtime)
 
     def check_open_write_flush_close_non_w_mode(self):
         """
@@ -364,13 +364,13 @@ class FakeStatTestBase(RealFsTestCase):
 
         self.assertEqual(before.st_atime, opened.st_atime)
         self.assertEqual(opened.st_atime, written.st_atime)
-        self.assertEqual(written.st_atime, flushed.st_atime)
+        self.assertLessEqual(written.st_atime, flushed.st_atime)
         self.assertEqual(flushed.st_atime, closed.st_atime)
 
         self.assertEqual(before.st_mtime, opened.st_mtime)
         self.assertEqual(opened.st_mtime, written.st_mtime)
         self.assertLessExceptWindows(written.st_mtime, flushed.st_mtime)
-        self.assertLessExceptPosix(flushed.st_mtime, closed.st_mtime)
+        self.assertLessEqual(flushed.st_mtime, closed.st_mtime)
 
 
 class TestFakeModeW(FakeStatTestBase):
@@ -398,7 +398,7 @@ class TestFakeModeW(FakeStatTestBase):
 
     def test_read_raises(self):
         with self.open(self.file_path, 'w') as f:
-            with self.assertRaises(IOError):
+            with self.assertRaises(OSError):
                 f.read()
 
 
@@ -440,7 +440,7 @@ class TestFakeModeWPlus(FakeStatTestBase):
         self.assertEqual(opened.st_ctime, read.st_ctime)
         self.assertEqual(read.st_ctime, closed.st_ctime)
 
-        self.assertEqual(before.st_atime, opened.st_atime)
+        self.assertLessEqual(before.st_atime, opened.st_atime)
         self.assertLessEqual(opened.st_atime, read.st_atime)
         self.assertEqual(read.st_atime, closed.st_atime)
 
@@ -485,7 +485,7 @@ class TestFakeModeA(FakeStatTestBase):
 
     def test_read_raises(self):
         with self.open(self.file_path, 'a') as f:
-            with self.assertRaises(IOError):
+            with self.assertRaises(OSError):
                 f.read()
 
 
@@ -566,7 +566,7 @@ class TestFakeModeR(FakeStatTestBase):
         self.assertEqual(flushed.st_mtime, closed.st_mtime)
 
     def test_open_not_existing_raises(self):
-        with self.assertRaises(IOError):
+        with self.assertRaises(OSError):
             with self.open(self.file_path, 'r'):
                 pass
 
@@ -597,7 +597,7 @@ class TestFakeModeRPlus(FakeStatTestBase):
         self.check_open_write_flush_close_non_w_mode()
 
     def test_open_not_existing_raises(self):
-        with self.assertRaises(IOError):
+        with self.assertRaises(OSError):
             with self.open(self.file_path, 'r+'):
                 pass
 
